#!/bin/sh

if [ "$1" = "start_sshd" ] ; then
        /etc/init.d/ssh start
fi

if [ "$1" = "stop_sshd" ] ; then
        /etc/init.d/ssh stop
fi

if [ "$1" = "kill_sshd" ] ; then
        killall sshd
fi

if [ "$1" = "disable_respawn" ] ; then
        sed -i 's/respawn/#respawn/g' /etc/event.d/sshd
fi

if [ "$1" = "create_sshd" ] ; then
        echo "#start on stopped rcS" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "console output" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "#respawn" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "pre-start script" >> /etc/event.d/sshd
        echo "    if [ ! -d /var/run/sshd ] ; then" >> /etc/event.d/sshd
        echo "        mkdir /var/run/sshd" >> /etc/event.d/sshd
        echo "        chmod 755 /var/run/sshd" >> /etc/event.d/sshd
        echo "    fi" >> /etc/event.d/sshd
        echo "end script" >> /etc/event.d/sshd
        echo "" >> /etc/event.d/sshd
        echo "exec /usr/sbin/sshd" >> /etc/event.d/sshd
fi

if [ "$1" = "insert_start" ] ; then
        sed -i '1i#start on stopped rcS' /etc/event.d/sshd
fi

if [ "$1" = "disable_autostart" ] ; then
        sed -i 's/start on stopped rcS/#start on stopped rcS/g' /etc/event.d/sshd
fi

if [ "$1" = "enable_autostart" ] ; then
        sed -i 's/#start on stopped rcS/start on stopped rcS/g' /etc/event.d/sshd
fi

if [ "$1" = "disable_wifipm" ] ; then
        iwconfig wlan0 power off
fi

if [ "$1" = "enable_wifipm" ] ; then
        iwconfig wlan0 power on
fi
